@@ -416,7 +416,8 @@ void AddresseeLineEditPrivate::akonadiPerformSearch()
     qCDebug(LIBKDEPIMAKONADI_LOG) << "searching akonadi with:" << mSearchString;
 
     // first, kill all job still in flight, they are no longer current
-    for (const QPointer<Akonadi::Job> &job : qAsConst(AddresseeLineEditManager::self()->akonadiJobsInFlight)) {
+    const auto akonadiJobsInFlight = AddresseeLineEditManager::self()->akonadiJobsInFlight;
+    for (const QPointer<Akonadi::Job> &job : akonadiJobsInFlight) {
         if (!job.isNull()) {
             job.data()->kill();
         }
